// Sleipnir݊̐ݒ



// Advanced

pref('browser.tabs.extensions.window_hook_mode', 2);
pref('browser.tabs.extensions.cancel_windowclose', 0);
pref("browser.tabs.extensions.close_only_tab", true);

pref('browser.tabs.opentabfor.urlbar', true);
pref('browser.tabs.opentabfor.linkclick', true);
pref('browser.tabs.opentabfor.bookmarks', true);
pref('browser.tabs.opentabfor.history', false);
pref('browser.tabs.opentabfor.windowopen', true);

pref("browser.tabs.extensions.platform_native.behavior", 2);




// Startup

pref('browser.tabs.extensions.startup_action_overlay', 0);
pref('browser.tabs.extensions.last_tab_closing', 3);
pref('browser.tabs.autoHide', false);
pref('browser.tabs.extensions.ondblclick', 2);



// Focus

pref('browser.tabs.loadInBackground', true);
pref("browser.tabs.extensions.loadInBackgroundLinks", true);
pref('browser.tabs.extensions.loadInBackgroundMiddleClick', true);
pref('browser.tabs.extensions.loadInBackgroundBookmarks', true);
pref('browser.tabs.extensions.loadInBackgroundHistory', true);
pref('browser.tabs.extensions.loadInBackgroundJS', true);
pref('browser.tabs.extensions.loadInBackgroundPlatformNative', true);
pref('browser.tabs.extensions.direction_of_focusing', 0);



// Advanced Use

pref('browser.tabs.opentabfor.urlbar_always', false);
pref('browser.tabs.opentabfor.anybookmark', true);
pref('browser.tabs.opentabfor.anyhistory', true);


// Misc
pref("browser.tabs.extensions.ignore_target", true);
